@@ -1,4 +1,5 @@
 import http.client
+import urllib.parse as urlparse
 import json
 
 
@@ -15,7 +16,7 @@ class CreatePayoutAccount:
         headers = {"Content-type": "application/json",
                    "Accept": "application/json"}
 
-        url_info = urlparse.urlparse(self.endpoint)
+        url_info = urlparse(self.endpoint)
         if url_info.scheme == "https":
             conn = httplib.HTTPSConnection(
                 url_info.hostname, url_info.port or 443)
