@@ -11,7 +11,6 @@ class Payout:
         conn = http.client.HTTPSConnection("reddash.azurewebsites.net")
         route = "/app/endpoints/" + self.app
         headers = {"Accept": "application/json"}
-        # Send the request
         conn.request("POST", route, "", headers)
         response = json.loads(conn.getresponse().read().decode())
         # Parse and set dataEndpoints
@@ -19,18 +18,17 @@ class Payout:
             self.dataEndpoints = response["dataEndpoints"]
         else:
             self.dataEndpoints = "ERROR Unable to get dataEndpoints from server"
-        print("dataEndpoints -> " + self.dataEndpoints)
-
+        # print("dataEndpoints -> " + self.dataEndpoints)
         # Parse and set redpayEndpoints
         if "redpayEndpoints" in response:
             self.redpayEndpoints = response["redpayEndpoints"]
         else:
             self.redpayEndpoints = "ERROR Unable to get redpayEndpoints from server"
-        print("redpayEndpoints -> " + self.redpayEndpoints)
+        # print("redpayEndpoints -> " + self.redpayEndpoints)
 
     def CreatePayoutAccount(self, request):
         create_payout_account = CreatePayoutAccount(
-            self.app, self.dataEndpoints)
+            self.app, self.key, self.dataEndpoints)
         return create_payout_account.Process(request)
 
     def UpdatePayoutAccount(self, request):
